@@ -34,15 +34,11 @@
 #' @examples
 #' # 1000 95% intervals using t.test; population is N(0,1)
 #' CIsim(n=10, samples=1000)    
-#' # this time population is Exp(1)
-#' CIsim(n=10, samples=1000, rdist=rexp, estimand=1)    
-#' # fewer samples, so we get a plot 
+#' # this time population is Exp(1); fewer samples, so we get a plot 
 #' CIsim(n=10, samples=100, rdist=rexp, estimand=1) 
 #' # Binomial treats 1 like success, 0 like failure
 #' CIsim(n=30, samples=100, rdist=rbinom, args=list(size=1, prob=.7), 
-#'        estimand = .7, method = prop.test)  
-#' CIsim(n=30, samples=100, rdist=rbinom, args=list(size=1, prob=.7), 
-#'        estimand = .7, method = binom.test)
+#'        estimand = .7, method = binom.test, method.args=list(ci = "Plus4"))  
 #' 
 #' @keywords inference 
 #' @keywords simulation 
@@ -88,7 +84,8 @@ CIsim <-
     plotG <- 
       ggplot(aes(x=sample, y=estimate, ymin=lower, ymax=upper), data = cis) + 
         geom_errorbar(aes(color=cover)) +
-        geom_abline(slope=0, intercept=estimand, alpha=0.4)
+        geom_abline(slope=0, intercept=estimand, alpha=0.4) +
+        scale_colour_discrete(drop = FALSE)
       
     switch(plot,
            return = return(plotG),
