@@ -137,7 +137,7 @@ aggregatingFunction2 <- function( fun ) {
       }
     }
     if (! is.null(condition(formula)) ) {
-      stop( "Formula must of form y ~ x." )
+      stop( "Formula must be of the form y ~ x." )
     }
     return( eval(mosaic.call) )
   }
@@ -220,6 +220,10 @@ cor <- aggregatingFunction2( stats::cor )
 #' if (require(mosaicData)) {
 #' mean( HELPrct$age )
 #' mean( ~ age, data=HELPrct )
+#' mean( age ~ shuffle(sex), data=HELPrct)
+#' mean( age ~ shuffle(sex), data=HELPrct, .format="table")
+#' # wrap in data.frame() to auto-convert awkward variable names
+#' data.frame(mean( age ~ shuffle(sex), data=HELPrct, .format="table"))
 #' mean( age ~ sex + substance, data=HELPrct )
 #' mean( ~ age | sex + substance, data=HELPrct )
 #' mean( sqrt(age), data=HELPrct )
