@@ -25,12 +25,13 @@
 #' When there are multiple \code{TRUE} rules for a slot, the first or last such is used
 #' or an error is generated, depending on the value of \code{method}.   
 #' 
-#' \code{derivedFactor} is designed to be used with \code{transform} to add new 
+#' \code{derivedFactor} is designed to be used with \code{\link{transform}} or 
+#' \code{\link[dplyr]{mutate}} to add new 
 #' factor variables to a data frame.  See the examples.
 #' 
 #' @examples
 #' if (require(mosaicData)) {
-#' Kf <- transform(KidsFeet, biggerfoot2=derivedFactor(
+#' Kf <- mutate(KidsFeet, biggerfoot2=derivedFactor(
 #'                    dom = biggerfoot == domhand,
 #'                    nondom = biggerfoot != domhand)
 #'                    )
@@ -39,7 +40,7 @@
 #' 
 #' # Three equivalent ways to define a new variable
 #' # Method 1: explicitly define all levels
-#' modHELP <- transform(HELPrct, drinkstat = derivedFactor( 
+#' modHELP <- mutate(HELPrct, drinkstat = derivedFactor( 
 #'   abstinent = i1 == 0,
 #'   moderate = (i1>0 & i1<=1 & i2<=3 & sex=='female') |
 #'      (i1>0 & i1<=2 & i2<=4 & sex=='male'),
@@ -50,7 +51,7 @@
 #' tally( ~drinkstat, data=modHELP )
 #'
 #' # Method 2: Use .default for last level
-#' modHELP <- transform(HELPrct, drinkstat = derivedFactor( 
+#' modHELP <- mutate(HELPrct, drinkstat = derivedFactor( 
 #'   abstinent = i1 == 0,
 #'   moderate = (i1<=1 & i2<=3 & sex=='female') |
 #'      (i1<=2 & i2<=4 & sex=='male'),
@@ -61,7 +62,7 @@
 #' tally( ~drinkstat, data=modHELP )
 #' 
 #' # Method 3: use TRUE to catch any fall through slots
-#' modHELP <- transform(HELPrct, drinkstat = derivedFactor( 
+#' modHELP <- mutate(HELPrct, drinkstat = derivedFactor( 
 #'   abstinent = i1 == 0,
 #'   moderate = (i1<=1 & i2<=3 & sex=='female') |
 #'      (i1<=2 & i2<=4 & sex=='male'),
@@ -102,10 +103,12 @@ derivedFactor <- function(...,
     rulesM <- do.call(cbind, rules)
   }
   
-  lastApplicableRule  <- apply( rulesM, 1, 
-                                function(x) max(which(x), na.rm=TRUE) )
-  firstApplicableRule <- apply( rulesM, 1, 
-                                function(x) min(which(x), na.rm=TRUE) )
+  lastApplicableRule  <- 
+    apply( rulesM, 1, 
+           function(x) if (all(is.na(x))) NA else max(which(x), na.rm=TRUE) )
+  firstApplicableRule <- 
+    apply( rulesM, 1, 
+           function(x) if (all(is.na(x))) NA else min(which(x), na.rm=TRUE) )
   firstApplicableRule[firstApplicableRule == Inf] <- NA
   lastApplicableRule[lastApplicableRule == -Inf] <- NA
   
