@@ -491,57 +491,6 @@ fortify.TukeyHSD <- function(model, data, ...) {
   return(plotData)
 }  
 
-#' @rdname mplot
-#' @examples
-#' if (require(mosaicData)) {
-#' mplot(TukeyHSD( lm(age ~ substance, data=HELPrct) ) )
-#' mplot(TukeyHSD( lm(age ~ substance, data=HELPrct) ), system="ggplot2" )
-#' }
-#' @export
-
-mplot.TukeyHSD <- function(object, system=c("lattice", "ggplot2"), 
-                           ylab="", xlab="difference in means", 
-                           title="Tukey's Honest Significant Differences",
-                           par.settings=trellis.par.get(),
-                           ...) {
-  
-  system = match.arg(system)
-  fdata <- fortify(object)
-  
-  if (system=="ggplot2") {
-    return(
-      ggplot( data=fdata,
-              aes(x=diff, color=log10(pval), y=pair) ) +
-        geom_point(size=2) +
-        geom_segment(aes(x=lwr, xend=upr, y=pair, yend=pair) ) +
-        geom_vline( xintercept=0, color="red", linetype=2, alpha=.5 ) + 
-        facet_grid( var ~ ., scales = "free_y") +
-        labs(x=xlab, y=ylab, title=title)
-    )
-  }
-
-  cols <- par.settings$superpose.line$col[1 + 
-            as.numeric( sign(fdata$lwr) * sign(fdata$upr) < 0)]
-  return( 
-    xyplot( pair ~ diff + lwr + upr | var, data=fdata, 
-            panel=function(x,y,subscripts,...) {
-              n <- length(x)
-              m <- round(n/3)
-              panel.abline(v=0, col="red", lty=2, alpha=.5)
-              panel.segments(x0=x[(m+1):(2*m)], x1=x[(2*m+1):(3*m)], y0=y, y1=y, col=cols[subscripts])
-              panel.xyplot(x[1:m], y, cex=1.4, pch=16, col=cols[subscripts])
-            },
-            scales = list( y=list(relation="free", rot=30) ),
-            xlab=xlab,
-            ylab=ylab,
-            main=title,
-            ...
-    )
-  )
-  
-}
-
-
 #' @rdname fortify
 #' @param model an R object
 #' @param data original data set, if needed
@@ -588,12 +537,12 @@ mplot.TukeyHSD <- function(object, system=c("lattice", "ggplot2"),
   if (system=="ggplot2") {
     return(
       ggplot( data=fdata,
-              aes(x=diff, color=log10(pval), y=pair) ) +
+              aes(x=diff, color=log10(pval), y=factor(pair, levels=rev(levels(pair)))) ) +
         geom_point(size=2) +
         geom_segment(aes(x=lwr, xend=upr, y=pair, yend=pair) ) +
         geom_vline( xintercept=0, color="red", linetype=2, alpha=.5 ) + 
         facet_grid( var ~ ., scales = "free_y") +
-        labs(x=xlab, y=ylab, title=title)
+        labs(x=xlab, y=ylab, title=title) 
     )
   }
 
@@ -601,7 +550,7 @@ mplot.TukeyHSD <- function(object, system=c("lattice", "ggplot2"),
             as.numeric( sign(fdata$lwr) * sign(fdata$upr) < 0)]
     
   return( 
-    xyplot( pair ~ diff + lwr + upr | var, data=fdata, 
+    xyplot( factor(pair, levels=rev(levels(pair))) ~ diff + lwr + upr | var, data=fdata, 
             panel=function(x,y,subscripts,...) {
               n <- length(x)
               m <- round(n/3)
